pub struct RowMetadataRegistry { /* private fields */ }Expand description
Registry that manages metadata sources for different tables. Provides a centralized way to register and retrieve metadata sources that can be used to obtain row-level metadata for tables.
Implementations
Sourceimpl RowMetadataRegistry
impl RowMetadataRegistry
Sourcepub fn new_with_default_source(
default_source: Arc<dyn RowMetadataSource>,
) -> Self
pub fn new_with_default_source( default_source: Arc<dyn RowMetadataSource>, ) -> Self
Initializes this RowMetadataRegistry with a default RowMetadataSource
to be used if a table has not been explicitly registered with a specific source.
Typically the FileMetadata source should be used as the default.
Sourcepub fn new_empty() -> Self
pub fn new_empty() -> Self
Initializes a new RowMetadataRegistry with no default RowMetadataSource.
Users should typically use RowMetadataRegistry::new_with_default_source.
Sourcepub fn register_source(
&self,
table: &ResolvedTableReference,
source: Arc<dyn RowMetadataSource>,
) -> Option<Arc<dyn RowMetadataSource>>
pub fn register_source( &self, table: &ResolvedTableReference, source: Arc<dyn RowMetadataSource>, ) -> Option<Arc<dyn RowMetadataSource>>
Registers a metadata source for a specific table. Returns the previously registered source for this table, if any
Sourcepub fn get_source(
&self,
table: &ResolvedTableReference,
) -> Result<Arc<dyn RowMetadataSource>>
pub fn get_source( &self, table: &ResolvedTableReference, ) -> Result<Arc<dyn RowMetadataSource>>
Retrieves the registered RowMetadataSource for a specific table.