pub struct OneOf { /* private fields */ }Expand description
A custom logical plan node that denotes multiple equivalent sub-expressions in a logical plan. Used for rewriting queries to use available materialized views, where beneficial.