pub struct ViewMatcher { /* private fields */ }Expand description
A logical optimizer that generates candidate logical plans in the form of OneOf nodes.
Implementations
Sourceimpl ViewMatcher
impl ViewMatcher
Sourcepub async fn try_new_from_state(session_state: &SessionState) -> Result<Self>
pub async fn try_new_from_state(session_state: &SessionState) -> Result<Self>
Loads table information and processes all views, returning a new optimizer rule.