pub trait Materialized: ListingTableLike {
// Required method
fn query(&self) -> LogicalPlan;
// Provided methods
fn config(&self) -> MaterializedConfig { ... }
fn static_partition_columns(&self) -> Vec<String> { ... }
}Expand description
A hive-partitioned table in object storage that is defined by a user-provided query.
Required Methods
Sourcefn query(&self) -> LogicalPlan
fn query(&self) -> LogicalPlan
The query that defines this materialized view.
Provided Methods
Sourcefn config(&self) -> MaterializedConfig
fn config(&self) -> MaterializedConfig
Configuration to control materialized view related features.
By default, returns the default value for MaterializedConfig
Sourcefn static_partition_columns(&self) -> Vec<String>
fn static_partition_columns(&self) -> Vec<String>
Which partition columns are ‘static’.
Static partition columns are those that are used in incremental view maintenance.
These should be a prefix of the full set of partition columns returned by ListingTableLike::partition_columns.
The rest of the partition columns are ‘dynamic’ and their values will be generated at runtime during incremental refresh.