pub struct SpjNormalForm { /* private fields */ }Expand description
A normalized representation of a plan containing only Select/Project/Join in the relational algebra sense. In DataFusion terminology this also includes Filter nodes. Joins are not currently supported, but are planned.
Implementations
Sourceimpl SpjNormalForm
impl SpjNormalForm
Sourcepub fn output_schema(&self) -> &Arc<DFSchema>
pub fn output_schema(&self) -> &Arc<DFSchema>
Schema of data output by this plan.
Sourcepub fn output_exprs(&self) -> &[Expr]
pub fn output_exprs(&self) -> &[Expr]
Expressions output by this plan. These expressions can be used to rewrite this plan as a cross join followed by a projection; however, this does not include any filters in the original plan, so the result will be a superset.
Sourcepub fn referenced_tables(&self) -> &[TableReference]
pub fn referenced_tables(&self) -> &[TableReference]
All tables referenced in this plan.
Sourcepub fn new(original_plan: &LogicalPlan) -> Result<Self>
pub fn new(original_plan: &LogicalPlan) -> Result<Self>
Analyze an existing LogicalPlan and rewrite it in select-project-join normal form.
Sourcepub fn rewrite_from(
&self,
other: &Self,
qualifier: TableReference,
source: Arc<dyn TableSource>,
) -> Result<Option<LogicalPlan>>
pub fn rewrite_from( &self, other: &Self, qualifier: TableReference, source: Arc<dyn TableSource>, ) -> Result<Option<LogicalPlan>>
Rewrite this plan as as selection/projection on top of another plan,
which we use qualifier to refer to.
This is useful for rewriting queries to use materialized views.